@@ -45,6 +45,4 @@ def httpx_exception():
 
 httpx_exception()
 
-client = AnimeHttpClient(
-    headers=headers, follow_redirects=True, timeout=30.0
-)
+client = AnimeHttpClient(headers=headers, follow_redirects=True, timeout=30.0)
