@@ -4,6 +4,8 @@ from ...providers.nineanime.decipher import cipher_keyed, encrypt
 
 EMBED_URL_REGEX = regex.compile(r"(.+?/)(?:e(?:mbed)?)/([a-zA-Z0-9]+)")
 
+BASE64_TABLE = "0wMrYU+ixjJ4QdzgfN2HlyIVAt3sBOZnCT9Lm7uFDovkb/EaKpRWhqXS5168ePcG"
+
 
 def extract(session, url, **opts):
 
@@ -13,9 +15,11 @@ def extract(session, url, **opts):
     vidstream_info = session.get(
         "{}info/{}".format(
             host,
-            encrypt(cipher_keyed("LCbu3iYC7ln24K7P", encrypt(slug))).replace("/", "_"),
+            encrypt(
+                cipher_keyed("LCbu3iYC7ln24K7P", encrypt(slug, table=BASE64_TABLE)),
+                table=BASE64_TABLE,
+            ).replace("/", "_"),
         ),
-        headers={"referer": url},
     )
 
     if vidstream_info.status_code == 404:
